==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/HighDensityScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescriptionMetadata } from "./ProgressiveLoadStatusEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { HighDensityScatterSeriesDescription } from "./HighDensityScatterSeriesDescription";
/**
 * @hidden
 */
export let HighDensityScatterSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HighDensityScatterSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HighDensityScatterSeriesDescriptionMetadata.a == null) {
                HighDensityScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HighDensityScatterSeriesDescriptionMetadata.c(HighDensityScatterSeriesDescriptionMetadata.a);
            }
            if (a.k(HighDensityScatterSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(HighDensityScatterSeriesDescriptionMetadata.a);
            ProgressiveLoadStatusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
            a.item("XMemberPath", "String");
            a.item("XMemberAsLegendLabel", "String");
            a.item("YMemberAsLegendLabel", "String");
            a.item("XMemberAsLegendUnit", "String");
            a.item("YMemberAsLegendUnit", "String");
            a.item("YMemberPath", "String");
            a.item("UseBruteForce", "Boolean");
            a.item("ProgressiveLoad", "Boolean");
            a.item("HeatMinimum", "Number:double");
            a.item("HeatMaximum", "Number:double");
            a.item("HeatMinimumColor", "Color");
            a.item("HeatMaximumColor", "Color");
            a.item("PointExtent", "Number:int");
            a.item("ProgressiveStatus", "Number:int");
            a.item("ProgressiveLoadStatusChangedRef", "EventRef::progressiveLoadStatusChanged");
        }
        static d(a) {
            HighDensityScatterSeriesDescriptionMetadata.b(a);
            a.ad("HighDensityScatterSeries", () => new HighDensityScatterSeriesDescription());
            a.ac("HighDensityScatterSeries", HighDensityScatterSeriesDescriptionMetadata.a);
        }
    }
    HighDensityScatterSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(HighDensityScatterSeriesDescriptionMetadata, 'HighDensityScatterSeriesDescriptionMetadata');
    HighDensityScatterSeriesDescriptionMetadata.a = null;
    return HighDensityScatterSeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/HighDensityScatterSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProgressiveLoadStatusEventArgsDescriptionMetadata } from "./ProgressiveLoadStatusEventArgsDescriptionMetadata";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { HighDensityScatterSeriesDescription } from "./HighDensityScatterSeriesDescription";
/**
 * @hidden
 */
export let HighDensityScatterSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HighDensityScatterSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HighDensityScatterSeriesDescriptionMetadata.a == null) {
                HighDensityScatterSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HighDensityScatterSeriesDescriptionMetadata.c(HighDensityScatterSeriesDescriptionMetadata.a);
            }
            if (a.k(HighDensityScatterSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(HighDensityScatterSeriesDescriptionMetadata.a);
            ProgressiveLoadStatusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            SeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
            a.item("XMemberPath", "String");
            a.item("XMemberAsLegendLabel", "String");
            a.item("YMemberAsLegendLabel", "String");
            a.item("XMemberAsLegendUnit", "String");
            a.item("YMemberAsLegendUnit", "String");
            a.item("YMemberPath", "String");
            a.item("UseBruteForce", "Boolean");
            a.item("ProgressiveLoad", "Boolean");
            a.item("HeatMinimum", "Number:double");
            a.item("HeatMaximum", "Number:double");
            a.item("HeatMinimumColor", "Color");
            a.item("HeatMaximumColor", "Color");
            a.item("PointExtent", "Number:int");
            a.item("ProgressiveStatus", "Number:int");
            a.item("ProgressiveLoadStatusChangedRef", "EventRef::progressiveLoadStatusChanged");
        }
        static d(a) {
            HighDensityScatterSeriesDescriptionMetadata.b(a);
            a.ae("HighDensityScatterSeries", () => new HighDensityScatterSeriesDescription());
            a.ad("HighDensityScatterSeries", HighDensityScatterSeriesDescriptionMetadata.a);
        }
    }
    HighDensityScatterSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(HighDensityScatterSeriesDescriptionMetadata, 'HighDensityScatterSeriesDescriptionMetadata');
    HighDensityScatterSeriesDescriptionMetadata.a = null;
    return HighDensityScatterSeriesDescriptionMetadata;
})();
